pub struct DirectionalLight { /* private fields */ }Implementations
Methods from Deref<Target = DirectionalLight>
Sourcepub fn set_direction(&mut self, x: f32, y: f32, z: f32)
pub fn set_direction(&mut self, x: f32, y: f32, z: f32)
Set the direction of the light the light points in the direction of the vector
Sourcepub fn get_direction(&self) -> [f32; 3]
pub fn get_direction(&self) -> [f32; 3]
Get the direction of the light the light points in the direction of the vector
Sourcepub fn set_color(&mut self, r: f32, g: f32, b: f32)
pub fn set_color(&mut self, r: f32, g: f32, b: f32)
Set the color of the light in 0.0 - 1.0 range
Sourcepub fn set_intensity(&mut self, intensity: f32)
pub fn set_intensity(&mut self, intensity: f32)
Set the intensity of the light If the intensity is above 1.0, it can result in overexposure
Sourcepub fn set_angular_falloff(&mut self, angular_falloff: f32)
pub fn set_angular_falloff(&mut self, angular_falloff: f32)
Set the angular falloff of the light 0.0 is no falloff, 1.0 is full falloff
Sourcepub fn set_distance_falloff(&mut self, distance_falloff: f32)
pub fn set_distance_falloff(&mut self, distance_falloff: f32)
Set the distance falloff of the light 0.0 is no falloff, 1.0 is full falloff