pub struct LumenpyxEventLoop { /* private fields */ }Expand description
The event loop for the lumenpyx program
Implementations
Sourceimpl LumenpyxEventLoop
impl LumenpyxEventLoop
Sourcepub fn new(world: &mut World, resolution: [u32; 2], name: &str) -> Self
pub fn new(world: &mut World, resolution: [u32; 2], name: &str) -> Self
create a new lumenpyx event loop puts the lumenpyx program in the world as a resource so it can be accessed by the update function
Sourcepub fn set_render_settings(
&mut self,
world: &mut World,
settings: RenderSettings,
)
pub fn set_render_settings( &mut self, world: &mut World, settings: RenderSettings, )
set the render settings for the program this is a convenience function for setting the render settings
Sourcepub fn set_debug(&mut self, world: &mut World, options: DebugOption)
pub fn set_debug(&mut self, world: &mut World, options: DebugOption)
set the debug options for the program this is a convenience function for setting the debug options
Sourcepub fn set_name(&mut self, world: &mut World, name: &str)
pub fn set_name(&mut self, world: &mut World, name: &str)
set the name of the window this is a convenience function for setting the name of the window
Sourcepub fn set_resolution(&mut self, world: &mut World, resolution: [u32; 2])
pub fn set_resolution(&mut self, world: &mut World, resolution: [u32; 2])
set the resolution of the window this is a convenience function for setting the resolution of the window
Sourcepub fn get_resolution(&self, world: &World) -> [u32; 2]
pub fn get_resolution(&self, world: &World) -> [u32; 2]
get the resolution of the window this is a convenience function for getting the resolution of the window returns the resolution as a [u32; 2]